#!/bin/sh

#-----------------------------------------------------
#Copyright (c): 2017, Huawei Tech. Co., Ltd.
#FileName     : sslcert_env.sh
#Version      : Gauss200 OLAP
#Date         : 2017-04-06
#Description  : This file is to configure environment variables of certifications.
#-----------------------------------------------------


#find the absolute path of this script
curpath=$0
if [ x${curpath:0:1} = "x-" ] || [ x${curpath} = "x/bin/bash" ] || [ x${curpath} = "x/bin/sh" ]; then
	curpath="`pwd`"
elif [ x${curpath:0:1} != "x/" ]; then
	curpath="`pwd`/`dirname ${curpath}`";
fi

unset PGSSLCERT_TMP
unset PGSSLKEY_TMP
[ -f "${curpath}/sslcert/client.crt" ] && PGSSLCERT_TMP="${curpath}/sslcert/client.crt"
[ -f "${curpath}/client.crt" ] && PGSSLCERT_TMP="${curpath}/client.crt"
[ -f "${curpath}/sslcert/client.key" ] && PGSSLKEY_TMP="${curpath}/sslcert/client.key"
[ -f "${curpath}/client.key" ] && PGSSLKEY_TMP="${curpath}/client.key"

function logerr()
{
	printf "ERROR: $* \n" >&2
}

function loghint()
{
	printf "HINT: $* \n" >&2
}

function logwarning()
{
	printf "WARNING: $* \n" >&2
}

function doing()
{
	length_of_line=60
	printf "$1 ";
	for ((i=${#1};i<$length_of_line;i++)); do 
		printf '.';
	done;
	printf " "
}

#------------------------------
#       SSL things
#------------------------------
function configssl()
{
	# for normal client tools
	doing 'Configuring certifications and private keys for SSL'
	if [ ! -f "$PGSSLCERT_TMP" ] || [ ! -f "$PGSSLKEY_TMP" ]; then
		logerr "failed to locate certificate files, please source this file at where it is."
		return 1
	fi
	export PGSSLCERT="$PGSSLCERT_TMP"
	export PGSSLKEY="$PGSSLKEY_TMP"
	chmod 600 "$PGSSLKEY"*
	echo 'done'
	loghint 'To use SSL by JDBC, see the information of manual.'
}

if [ ! -z $1 ]; then
	echo "Usage:"
	echo "	source $0"
else
	configssl
	if [ 0 -eq $? ]; then
		echo 'All things done.'
	fi
fi
